`timescale 1ns / 1ps

/////////////////////////////////////////////////////////////////////
// Company:        Atmospheric Plasma Solutions
// Engineer:       Jim Hall
// 
// Create Date:    10/29/2020 
// Design Name:    SAFETY_UNIT_CPLD
// Module Name:    SAFETY_UNIT_CPLD_TOP 
// Project Name:   MK1 SAFETY UNIT
// Target Devices: EPM240T100I5N
// Tool versions:  Quartus Prime Lite Edition 20.1.0 Build 711
// Description: 
//
// Dependencies: 
//
// Revision: 
// Revision 0.01 - File Created
// Additional Comments: 
//
/////////////////////////////////////////////////////////////////////
module Mk1_Safety_Unit_CPLD_Top(
                              master_8mhz_clk,
										standby_led,
										mk1_pwr_on_led,
										mk1_comm_link_led,
										mk1_overcurrent_led,
										mk1_water_fault_led,
										mk1_pen_disabled_led,
										check_ckt_brkr_led,
										mk1_on_sw_n,
										spare_sw_n,
										rs232_rx_en_n,
										rs232_tx_en,
										serial_out,
										rs485_tx_en,
										rs485_rx_en_n,
										serial_in,
										ext_rs232_connected,
										test_out,
										mk1_power_good,
										turn_mk1_on,
										contactor_closed_n,
										overcurrent_fault_n,
										pwr_supply_relay_on,
										test_led
									);	
/*
** DEFINES *****************************************
*/
`define TRUE 		1'b1
`define FALSE 		1'b0
`define HI    		1'b1
`define LO    		1'b0
									
/*
********************************************************************
*   IO Port Declarations 
********************************************************************
*/

input	master_8mhz_clk;				// pin 12						

// Panel Switches
input	mk1_on_sw_n;					// pin 38
input	spare_sw_n;						// pin 39

// Panel LEDs 
output standby_led;					// pin 26   
output mk1_pwr_on_led;				// pin 27
output mk1_comm_link_led;			// pin 28
output mk1_overcurrent_led;		// pin 29
output mk1_water_fault_led;		// pin 34
output mk1_pen_disabled_led;   	// pin 35
output check_ckt_brkr_led;			// pin 36

// Serial Port 
output rs232_rx_en_n;				// pin 49
output rs232_tx_en;					// pin 50
input  ext_rs232_connected;		// pin 57
output rs485_tx_en;					// pin 53
output rs485_rx_en_n;				// pin 54
output serial_out;					// pin 52
input  serial_in;						// pin 55

// Debug Signals
output [6:0]test_out;            // pins 74-68

// Status Inputs
input mk1_power_good;				// pin 86
input contactor_closed_n;			// pin 91
input overcurrent_fault_n;			// pin 97

// Relay  Control Outputs
output turn_mk1_on;					// pin 89, actuates contactor0 
output pwr_supply_relay_on;		// pin 99

// Eval Board Test
output test_led;
								
/*
********************************************************************
*   Port Outputs Variable Declarations 
********************************************************************
*/

// Panel LEDs
reg standby_led;
reg mk1_pwr_on_led;
reg mk1_comm_link_led;
reg mk1_overcurrent_led;
reg mk1_water_fault_led;
reg mk1_pen_disabled_led;
reg check_ckt_brkr_led;

//Serial Port
reg rs232_rx_en_n;
reg rs232_tx_en;
reg rs485_tx_en;
reg rs485_rx_en_n;
reg serial_out;

// Debug
reg [6:0]test_out;

// Relay Control Outputs
reg turn_mk1_on;
reg pwr_supply_relay_on;

/*
** PARAMETERS ***************************************
*/
parameter MASTER_CLK_DIVISOR=26'h2000000;  // 32M 
//parameter COUNTER_SIZE = 25;
//parameter MAX_COUNT = 25'h1FFFFFF;
								

/*
********************************************************************
*   Internal Variable Declarations 
********************************************************************
*/
reg  reset_n;

//reg  clk_out;
//reg  [(COUNTER_SIZE-1):0]  clk_in_count;
//reg  toggle_state;

wire cpld_clock;

/*
********************************************************************
*     LOWER LEVEL MODULE INSTANTIATIONS
********************************************************************
*/
// The main functional units of the REPM CPLD are:
//

clock_divider (master_8mhz_clk, reset_n, test_led);
                   
							 
/*
********************************************************************
*   ASSIGN Statements
********************************************************************
*/
//assign test_led = clk_out;

/*
********************************************************************
*     PROCEDURAL CODE
********************************************************************
*/

initial
begin
  reset_n <= `LO;
  #25 reset_n <= `HI;
end


endmodule  // safety_unit_cpld()
 


